package com.zehong.system.service;

import java.util.List;

import com.alibaba.fastjson.JSONObject;
import com.zehong.system.domain.TUserGps;

/**
 * 【请填写功能名称】Service接口
 * 
 * @author zehong
 * @date 2024-02-29
 */
public interface ITUserGpsService 
{
    /**
     * 查询【请填写功能名称】
     * 
     * @param id 【请填写功能名称】ID
     * @return 【请填写功能名称】
     */
    public TUserGps selectTUserGpsById(Long id);

    /**
     * 查询【请填写功能名称】列表
     * 
     * @param tUserGps 【请填写功能名称】
     * @return 【请填写功能名称】集合
     */
    public List<TUserGps> selectTUserGpsList(TUserGps tUserGps);

    /**
     * 新增【请填写功能名称】
     * 
     * @param tUserGps 【请填写功能名称】
     * @return 结果
     */
    public int insertTUserGps(TUserGps tUserGps);

    /**
     * 修改【请填写功能名称】
     * 
     * @param tUserGps 【请填写功能名称】
     * @return 结果
     */
    public int updateTUserGps(TUserGps tUserGps);

    /**
     * 批量删除【请填写功能名称】
     * 
     * @param ids 需要删除的【请填写功能名称】ID
     * @return 结果
     */
    public int deleteTUserGpsByIds(Long[] ids);

    /**
     * 删除【请填写功能名称】信息
     * 
     * @param id 【请填写功能名称】ID
     * @return 结果
     */
    public int deleteTUserGpsById(Long id);

    /**
     * 获取当前位置
     * @param id 设备编号
     * @return
     */
    JSONObject getCurrentLocation(String id);

    /**
     * 获取登录用户当前位置
     * @return
     */
    JSONObject getCurrentLocationByUser() throws Exception;

    /**
     * 定位历史轨迹
     * @param id 设备编号
     * @param startTime 开始时间
     * @param endTime 结束时间
     * @return
     */
    JSONObject historyTrack(String id,String startTime,String endTime);
}
